@@ -8,12 +8,12 @@ use fil_actors_runtime::{
     actor_error, make_empty_map, make_map_with_root, resolve_to_id_addr, wasm_trampoline,
     ActorDowncast, ActorError, Map, INIT_ACTOR_ADDR,
 };
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::{to_vec, RawBytes};
 use fvm_shared::actor::builtin::CALLER_TYPES_SIGNABLE;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::Sign;
-use fvm_shared::blockstore::Blockstore;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::{to_vec, RawBytes};
 use fvm_shared::error::ExitCode;
 use fvm_shared::{MethodNum, HAMT_BIT_WIDTH, METHOD_CONSTRUCTOR};
 use num_derive::FromPrimitive;
@@ -56,12 +56,12 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&*INIT_ACTOR_ADDR))?;
 
         if params.signers.is_empty() {
-            return Err(actor_error!(ErrIllegalArgument; "Must have at least one signer"));
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT; "Must have at least one signer"));
         }
 
         if params.signers.len() > SIGNERS_MAX {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "cannot add more than {} signers",
                 SIGNERS_MAX
             ));
@@ -73,13 +73,13 @@ impl Actor {
         for signer in &params.signers {
             let resolved = resolve_to_id_addr(rt, signer).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to resolve addr {} to ID addr", signer),
                 )
             })?;
             if !dedup_signers.insert(resolved.id().expect("address should be resolved")) {
                 return Err(
-                    actor_error!(ErrIllegalArgument; "duplicate signer not allowed: {}", signer),
+                    actor_error!(USR_ILLEGAL_ARGUMENT; "duplicate signer not allowed: {}", signer),
                 );
             }
             resolved_signers.push(resolved);
@@ -87,22 +87,22 @@ impl Actor {
 
         if params.num_approvals_threshold > params.signers.len() as u64 {
             return Err(
-                actor_error!(ErrIllegalArgument; "must not require more approvals than signers"),
+                actor_error!(USR_ILLEGAL_ARGUMENT; "must not require more approvals than signers"),
             );
         }
 
         if params.num_approvals_threshold < 1 {
-            return Err(actor_error!(ErrIllegalArgument; "must require at least one approval"));
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT; "must require at least one approval"));
         }
 
         if params.unlock_duration < 0 {
-            return Err(actor_error!(ErrIllegalArgument; "negative unlock duration disallowed"));
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT; "negative unlock duration disallowed"));
         }
 
         let empty_root = make_empty_map::<_, ()>(rt.store(), HAMT_BIT_WIDTH)
             .flush()
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "Failed to create empty map")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "Failed to create empty map")
             })?;
 
         let mut st: State = State {
@@ -138,7 +138,7 @@ impl Actor {
 
         if params.value.sign() == Sign::Minus {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "proposed value must be non-negative, was {}",
                 params.value
             ));
@@ -146,12 +146,12 @@ impl Actor {
 
         let (txn_id, txn) = rt.transaction(|st: &mut State, rt| {
             if !st.is_signer(&proposer) {
-                return Err(actor_error!(ErrForbidden, "{} is not a signer", proposer));
+                return Err(actor_error!(USR_FORBIDDEN, "{} is not a signer", proposer));
             }
 
             let mut ptx = make_map_with_root(&st.pending_txs, rt.store()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to load pending transactions",
                 )
             })?;
@@ -169,14 +169,14 @@ impl Actor {
 
             ptx.set(t_id.key(), txn.clone()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to put transaction for propose",
                 )
             })?;
 
             st.pending_txs = ptx.flush().map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to flush pending transactions",
                 )
             })?;
@@ -206,12 +206,12 @@ impl Actor {
         let id = params.id;
         let (st, txn) = rt.transaction(|st: &mut State, rt| {
             if !st.is_signer(&approver) {
-                return Err(actor_error!(ErrForbidden; "{} is not a signer", approver));
+                return Err(actor_error!(USR_FORBIDDEN; "{} is not a signer", approver));
             }
 
             let ptx = make_map_with_root(&st.pending_txs, rt.store()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to load pending transactions",
                 )
             })?;
@@ -245,13 +245,13 @@ impl Actor {
 
         rt.transaction(|st: &mut State, rt| {
             if !st.is_signer(&caller_addr) {
-                return Err(actor_error!(ErrForbidden; "{} is not a signer", caller_addr));
+                return Err(actor_error!(USR_FORBIDDEN; "{} is not a signer", caller_addr));
             }
 
             let mut ptx = make_map_with_root::<_, Transaction>(&st.pending_txs, rt.store())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         "failed to load pending transactions",
                     )
                 })?;
@@ -260,38 +260,42 @@ impl Actor {
                 .delete(&params.id.key())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to pop transaction {:?} for cancel", params.id),
                     )
                 })?
                 .ok_or_else(|| {
-                    actor_error!(ErrNotFound, "no such transaction {:?} to cancel", params.id)
+                    actor_error!(
+                        USR_NOT_FOUND,
+                        "no such transaction {:?} to cancel",
+                        params.id
+                    )
                 })?;
 
             // Check to make sure transaction proposer is caller address
             if tx.approved.get(0) != Some(&caller_addr) {
                 return Err(
-                    actor_error!(ErrForbidden; "Cannot cancel another signers transaction"),
+                    actor_error!(USR_FORBIDDEN; "Cannot cancel another signers transaction"),
                 );
             }
 
             let calculated_hash = compute_proposal_hash(&tx, rt).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to compute proposal hash for (tx: {:?})", params.id),
                 )
             })?;
 
             if !params.proposal_hash.is_empty() && params.proposal_hash != calculated_hash {
                 return Err(actor_error!(
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "hash does not match proposal params"
                 ));
             }
 
             st.pending_txs = ptx.flush().map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to flush pending transactions",
                 )
             })?;
@@ -310,7 +314,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&receiver))?;
         let resolved_new_signer = resolve_to_id_addr(rt, &params.signer).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve address {}", params.signer),
             )
         })?;
@@ -318,14 +322,14 @@ impl Actor {
         rt.transaction(|st: &mut State, _| {
             if st.signers.len() >= SIGNERS_MAX {
                 return Err(actor_error!(
-                    ErrForbidden,
+                    USR_FORBIDDEN,
                     "cannot add more than {} signers",
                     SIGNERS_MAX
                 ));
             }
             if st.is_signer(&resolved_new_signer) {
                 return Err(actor_error!(
-                    ErrForbidden,
+                    USR_FORBIDDEN,
                     "{} is already a signer",
                     resolved_new_signer
                 ));
@@ -351,7 +355,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&receiver))?;
         let resolved_old_signer = resolve_to_id_addr(rt, &params.signer).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve address {}", params.signer),
             )
         })?;
@@ -359,19 +363,19 @@ impl Actor {
         rt.transaction(|st: &mut State, rt| {
             if !st.is_signer(&resolved_old_signer) {
                 return Err(actor_error!(
-                    ErrForbidden,
+                    USR_FORBIDDEN,
                     "{} is not a signer",
                     resolved_old_signer
                 ));
             }
 
             if st.signers.len() == 1 {
-                return Err(actor_error!(ErrForbidden; "Cannot remove only signer"));
+                return Err(actor_error!(USR_FORBIDDEN; "Cannot remove only signer"));
             }
 
             if !params.decrease && ((st.signers.len() - 1) as u64) < st.num_approvals_threshold {
                 return Err(actor_error!(
-                    ErrIllegalArgument,
+                    USR_ILLEGAL_ARGUMENT,
                     "can't reduce signers to {} below threshold {} with decrease=false",
                     st.signers.len(),
                     st.num_approvals_threshold
@@ -381,7 +385,7 @@ impl Actor {
             if params.decrease {
                 if st.num_approvals_threshold < 2 {
                     return Err(actor_error!(
-                        ErrIllegalArgument,
+                        USR_ILLEGAL_ARGUMENT,
                         "can't decrease approvals from {} to {}",
                         st.num_approvals_threshold,
                         st.num_approvals_threshold - 1
@@ -394,7 +398,7 @@ impl Actor {
             st.purge_approvals(rt.store(), &resolved_old_signer)
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         "failed to purge approvals of removed signer",
                     )
                 })?;
@@ -416,25 +420,25 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&receiver))?;
         let from_resolved = resolve_to_id_addr(rt, &params.from).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve address {}", params.from),
             )
         })?;
         let to_resolved = resolve_to_id_addr(rt, &params.to).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve address {}", params.to),
             )
         })?;
 
         rt.transaction(|st: &mut State, rt| {
             if !st.is_signer(&from_resolved) {
-                return Err(actor_error!(ErrForbidden; "{} is not a signer", from_resolved));
+                return Err(actor_error!(USR_FORBIDDEN; "{} is not a signer", from_resolved));
             }
 
             if st.is_signer(&to_resolved) {
                 return Err(
-                    actor_error!(ErrIllegalArgument; "{} is already a signer", to_resolved),
+                    actor_error!(USR_ILLEGAL_ARGUMENT; "{} is already a signer", to_resolved),
                 );
             }
 
@@ -447,7 +451,7 @@ impl Actor {
             st.purge_approvals(rt.store(), &from_resolved)
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         "failed to purge approvals of removed signer",
                     )
                 })?;
@@ -472,7 +476,9 @@ impl Actor {
         rt.transaction(|st: &mut State, _| {
             // Check if valid threshold value
             if params.new_threshold == 0 || params.new_threshold > st.signers.len() as u64 {
-                return Err(actor_error!(ErrIllegalArgument; "New threshold value not supported"));
+                return Err(
+                    actor_error!(USR_ILLEGAL_ARGUMENT; "New threshold value not supported"),
+                );
             }
 
             // Update threshold on state
@@ -494,14 +500,14 @@ impl Actor {
 
         if params.unlock_duration <= 0 {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "unlock duration must be positive"
             ));
         }
 
         if params.amount.is_negative() {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "amount to lock must be positive"
             ));
         }
@@ -509,7 +515,7 @@ impl Actor {
         rt.transaction(|st: &mut State, _| {
             if st.unlock_duration != 0 {
                 return Err(actor_error!(
-                    ErrForbidden,
+                    USR_FORBIDDEN,
                     "modification of unlock disallowed"
                 ));
             }
@@ -532,7 +538,7 @@ impl Actor {
         for previous_approver in &txn.approved {
             if *previous_approver == rt.message().caller() {
                 return Err(actor_error!(
-                    ErrForbidden,
+                    USR_FORBIDDEN,
                     "{} already approved this message",
                     previous_approver
                 ));
@@ -542,7 +548,7 @@ impl Actor {
         let st = rt.transaction(|st: &mut State, rt| {
             let mut ptx = make_map_with_root(&st.pending_txs, rt.store()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to load pending transactions",
                 )
             })?;
@@ -552,14 +558,14 @@ impl Actor {
 
             ptx.set(tx_id.key(), txn.clone()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to put transaction {} for approval", tx_id.0),
                 )
             })?;
 
             st.pending_txs = ptx.flush().map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to flush pending transactions",
                 )
             })?;
@@ -584,13 +590,13 @@ where
     RT: Runtime<BS>,
 {
     let mut out = RawBytes::default();
-    let mut code = ExitCode::Ok;
+    let mut code = ExitCode::OK;
     let mut applied = false;
     let threshold_met = txn.approved.len() as u64 >= st.num_approvals_threshold;
     if threshold_met {
         st.check_available(rt.current_balance(), &txn.value, rt.curr_epoch())
             .map_err(|e| {
-                actor_error!(ErrInsufficientFunds, "insufficient funds unlocked: {}", e)
+                actor_error!(USR_INSUFFICIENT_FUNDS, "insufficient funds unlocked: {}", e)
             })?;
 
         match rt.send(txn.to, txn.method, txn.params.clone(), txn.value.clone()) {
@@ -607,21 +613,21 @@ where
             let mut ptx = make_map_with_root::<_, Transaction>(&st.pending_txs, rt.store())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         "failed to load pending transactions",
                     )
                 })?;
 
             ptx.delete(&txn_id.key()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to delete transaction for cleanup",
                 )
             })?;
 
             st.pending_txs = ptx.flush().map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to flush pending transactions",
                 )
             })?;
@@ -646,25 +652,29 @@ where
         .get(&txn_id.key())
         .map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to load transaction {:?} for approval", txn_id),
             )
         })?
         .ok_or_else(|| {
-            actor_error!(ErrNotFound, "no such transaction {:?} for approval", txn_id)
+            actor_error!(
+                USR_NOT_FOUND,
+                "no such transaction {:?} for approval",
+                txn_id
+            )
         })?;
 
     if !proposal_hash.is_empty() {
         let calculated_hash = compute_proposal_hash(txn, rt).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to compute proposal hash for (tx: {:?})", txn_id),
             )
         })?;
 
         if proposal_hash != calculated_hash {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "hash does not match proposal params (ensure requester is an ID address)"
             ));
         }
@@ -736,7 +746,7 @@ impl ActorCode for Actor {
                 Self::lock_balance(rt, rt.deserialize_params(params)?)?;
                 Ok(RawBytes::default())
             }
-            None => Err(actor_error!(SysErrInvalidMethod, "Invalid method")),
+            None => Err(actor_error!(SYS_INVALID_METHOD, "Invalid method")),
         }
     }
 }
